Gradient Similarity (GSM)
=========================

.. automodule:: viqa.fr_metrics.gsm
    :exclude-members: GSM, gradient_similarity, gradient_similarity_3d


.. rubric:: Functions

.. currentmodule:: viqa.fr_metrics.gsm

.. autosummary::
    :toctree: generated/

    gradient_similarity
    gradient_similarity_3d


.. rubric:: Classes

.. currentmodule:: viqa.fr_metrics.gsm

.. autosummary::
    :toctree: generated/
    :template: class.rst

    GSM